@@ -22,7 +22,7 @@
  *
  * @author Miloslaw Smyk, <thorgal@wfmh.org.pl>
  *
- * $Id: pfspanoramic.cpp,v 1.2 2006/11/20 17:52:15 rafm Exp $
+ * $Id: pfspanoramic.cpp,v 1.3 2008/07/29 16:14:30 rafm Exp $
  */
 
 #include <map>
@@ -43,7 +43,7 @@ class QuietException
 
 const double EPSILON=1e-7;
 
-static void errorCheck( bool condition, char *string )
+static void errorCheck( bool condition, const char *string )
 {
     if( !condition ) {
   fprintf( stderr, PROG_NAME " error: %s\n", string );
@@ -150,7 +150,7 @@ class Point2D
 class Projection
 {
   protected:
-  char *name;
+  const char *name;
   public:
     
     virtual Vector3D *uvToDirection(double u, double v) = 0;
@@ -165,7 +165,7 @@ class Projection
     {
     }
 
-    virtual char *getName(void)
+    virtual const char *getName(void)
     {
       return name;
     }
@@ -186,12 +186,12 @@ class ProjectionFactory
   public:
     map<string, ProjectionCreator> projections;
 
-    static void registerProjection(char *name, ProjectionCreator ptr)
+    static void registerProjection(const char *name, ProjectionCreator ptr)
     {
       singleton.projections[ string( name ) ] = ptr;
     }
 
-    static Projection *getProjection(char *name)
+    static Projection *getProjection(const char *name)
     {
       char *opts;
       
@@ -248,7 +248,7 @@ class MirrorBallProjection : public Projection
     return new MirrorBallProjection(false);
   }
 
-  char *getName(void)
+  const char *getName(void)
   {
     return name;
   }
@@ -363,7 +363,7 @@ class AngularProjection : public Projection
   }
 
 
-  char *getName(void)
+  const char *getName(void)
   {
     return name;
   }
