@@ -3,12 +3,8 @@
 	"usage: pfs_struct = pfsopen( fileName );\n"
 	"       pfs_struct = pfsopen( fileName, rows, columns );\n"
 	"       pfs_struct = pfsopen( fileName, [ rows columns ] );\n"
-	"       pfs_struct = pfsopen( fid );\n"
-	"       pfs_struct = pfsopen( fid, rows, columns );\n"
-	"       pfs_struct = pfsopen( fid, [ rows columns ] );\n"
 	"       \n"
 	"  fileName - name of the file to read or write. \"stdin\" or \"stdout\" for standard input and output\n"
-        "  fid - file identifier. pfsopen will make its own copy of this file handle, so 'fid' should be closed separatelly.\n"
 	"  rows - height of images to write\n"
 	"  columns - width of images to write\n"
 	"\n"
