@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: main.cpp,v 1.8 2007/11/20 11:44:12 rafm Exp $
+ * $Id: main.cpp,v 1.11 2008/10/02 22:42:01 rafm Exp $
  */
 
 #include <config.h>
@@ -110,6 +110,8 @@ PFSViewMainWin::PFSViewMainWin(  float window_min, float window_max ):
   pointerPosAndVal->setFont( fixedFont );
   zoomValue = new QLabel( statusBar );
   statusBar->addWidget( zoomValue );
+  exposureValue = new QLabel( statusBar );
+  statusBar->addWidget( exposureValue );
 
   connect( pfsView, SIGNAL(updatePointerValue()),
              this, SLOT(updatePointerValue()) );
@@ -255,7 +257,8 @@ PFSViewMainWin::PFSViewMainWin(  float window_min, float window_max ):
     if( !readNextFrame() ) 
       throw PFSViewException();
 
-    lumRange->setRangeWindowMinMax( window_min, window_max );  
+    if( window_min < window_max )
+      lumRange->setRangeWindowMinMax( window_min, window_max );  
     
   } catch( pfs::Exception ex ) {
     QMessageBox::critical( this, "pfsview error", ex.getMessage() );
@@ -322,7 +325,7 @@ void PFSViewMainWin::updatePointerValue()
       Y(0) = pv.value[1];
       Z(0) = pv.value[2];
 
-      char *l1, *l2, *l3;
+      const char *l1, *l2, *l3;
       switch( colorCoord ) {
       case CC_RGB:
         l1 = "R"; l2 = "G"; l3 = "B";
@@ -391,6 +394,11 @@ void PFSViewMainWin::updateViewSize()
 void PFSViewMainWin::updateRangeWindow()
 {
   pfsView->setRangeWindow( pow( 10, lumRange->getRangeWindowMin() ), pow( 10, lumRange->getRangeWindowMax() ) );
+
+  char ev_str[100];
+  sprintf( ev_str, "EV = %+.2g f-stops   %+.2g D   %.4g",  -lumRange->getRangeWindowMax()*log(2)/log(10),
+    -lumRange->getRangeWindowMax(), 1/pow( 10, lumRange->getRangeWindowMax() ) );
+  exposureValue->setText( ev_str );
 }
 
 void PFSViewMainWin::updateChannelSelection()
@@ -501,14 +509,20 @@ void PFSViewMainWin::setFrame( pfs::Frame *frame )
   pfsView->setFrame( frame );
 
   lumRange->setHistogramImage(pfsView->getPrimaryChannel());
-    
-  updateRangeWindow();
+
   updateChannelSelection();
   updateZoomValue();
+  
+  const char *luminanceTag = frame->getTags()->getString( "LUMINANCE" );
+  if( luminanceTag != NULL && !strcmp( luminanceTag, "DISPLAY" ) ) {
+    setLumMappingMethod(0);
+    lumRange->lowDynamicRange();
+  }
+  
+  updateRangeWindow();
 
   // Set the window caption to the name of the frame, if it is given
   const char *fileName = frame->getTags()->getString( "FILE_NAME" );
-  const char *luminanceTag = frame->getTags()->getString( "LUMINANCE" );
   QString qLuminance( "" );
   if( luminanceTag!=NULL )
     qLuminance=QString(" (") + QString(luminanceTag) + QString(")");
@@ -523,6 +537,7 @@ void PFSViewMainWin::setFrame( pfs::Frame *frame )
   }
   updateMenuEnable( );
 
+
   QApplication::restoreOverrideCursor();  
 }
 
@@ -600,7 +615,7 @@ void printUsage()
       );
 }
 
-static void errorCheck( bool condition, char *string )
+static void errorCheck( bool condition, const char *string )
 {
     if( !condition ) {
 	fprintf( stderr, PROGNAME " error: %s\n", string );
@@ -613,7 +628,7 @@ int main(int argc, char** argv)
     QApplication app(argc, argv);
     qApp = &app;
 
-    float window_min = 0, window_max = 2;
+    float window_min = 0, window_max = 0;
 
     for( int i=1 ; i<argc ; i++ )
     {
@@ -645,7 +660,7 @@ int main(int argc, char** argv)
       }
     }
 
-    errorCheck( window_min < window_max, "window_min must be less than window_max" );
+    errorCheck( window_min <= window_max, "window_min must be less than window_max" );
 
 
     try {
