@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfsview_widget.cpp,v 1.12 2007/11/20 11:44:12 rafm Exp $
+ * $Id: pfsview_widget.cpp,v 1.16 2009/05/11 18:05:21 rafm Exp $
  */
 
 #include <config.h>
@@ -70,10 +70,10 @@ const char* COLOR_CHANNELS = "Color";
 
 PFSViewWidget::PFSViewWidget( QWidget *parent, const char *name ) :
   QScrollView( parent, name, WRepaintNoErase ), image( NULL ),
-  minValue( 0.1f ), maxValue( 1.f ), zoom( 1.f ),
+  minValue( 1.f ), maxValue( 100.f ), zoom( 1.f ),
   mappingMethod( MAP_GAMMA2_2 ), visibleChannel( COLOR_CHANNELS ),
   negativeTreatment( NEGATIVE_BLACK ), infNaNTreatment( INFNAN_MARK_AS_RED ),
-  updateMappingRequested( true )
+  updateMappingRequested( true ), clippingMethod(CLIP_SIMPLE)
 {
   viewport()->setMouseTracking( true );
   viewport()->setCursor( QCursor( crossCursor ) );
@@ -373,11 +373,16 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
             pr == 0 || pg == 0 || pb == 0 ) {
             float p[3];
             p[0] = (*R)(index); p[1] = (*G)(index); p[2] = (*B)(index);
-            float gray = D65_LUM_R*p[0]+D65_LUM_G*p[1]+D65_LUM_B*p[2];
+            float gray = (p[0]+p[1]+p[2])/3.f;
+//            float gray = D65_LUM_R*p[0]+D65_LUM_G*p[1]+D65_LUM_B*p[2];
             float t;
 
-            int i;
-            if( gray < maxValue ) {
+            if( gray >= maxValue ) {
+              pixel = QColor( 255, 255, 255 ).rgb();
+            } else if( gray <= minValue ) {
+              pixel = QColor( 0, 0, 0 ).rgb();
+            } else {
+              int i;
               for( i = 0; i < 3; i++ ) {
                 t = (maxValue - p[i])/(gray - p[i]);             
                 if( t >= 0 && t <= 1 ) {
@@ -388,28 +393,27 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
                   break;
                 }              
               }
-            } else
-              i = 3;
             
-            if( i == 3 ) 
-              pixel = QColor( 255, 255, 255 ).rgb();
-            else {
-              for( int i = 0; i < 3; i++ )
-                p[i] = gray*t + p[i]*(1-t);
-
+              if( i == 3 ) 
+                pixel = QColor( 255, 255, 255 ).rgb();
+              else {
+                for( int i = 0; i < 3; i++ )
+                  p[i] = gray*t + p[i]*(1-t);
+                
 //               if( once ) {
 //                 printf( "min = %g max = %g\n", minValue, maxValue );
 //                 printf( "r = %g g = %g b = %g; t = %g\n", p[0], p[1], p[2], t );
 //                 once = false;
 //               }              
               
-              pr = binarySearchPixels( p[0], lutPixFloor, lutSize );        
-              pg = binarySearchPixels( p[1], lutPixFloor, lutSize );        
-              pb = binarySearchPixels( p[2], lutPixFloor, lutSize );
-              pixel = QColor( clamp( pr-1, 0, 255 ),
-                clamp( pg-1, 0, 255 ),
-                clamp( pb-1, 0, 255 ) ).rgb();
-            }
+                pr = binarySearchPixels( p[0], lutPixFloor, lutSize );        
+                pg = binarySearchPixels( p[1], lutPixFloor, lutSize );        
+                pb = binarySearchPixels( p[2], lutPixFloor, lutSize );
+                pixel = QColor( clamp( pr-1, 0, 255 ),
+                  clamp( pg-1, 0, 255 ),
+                  clamp( pb-1, 0, 255 ) ).rgb();
+              }
+            }  
           } else {
             pixel = QColor( clamp( pr-1, 0, 255 ),
               clamp( pg-1, 0, 255 ),
@@ -606,7 +610,7 @@ void PFSViewWidget::setPointer( int x, int y )
 {
   assert( pfsFrame != NULL );
 
-  if( x > 0 ) {    
+  if( x >= 0 ) {    
     pointerValue.x = x;
     pointerValue.y = y;
   }
